package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#``@````!````````'```````````0```````
M`*?H(```!P!``#@`"0!``!H`&0````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0```````">
MD````````)Z0````````GI``````````'``````````<``````````%P```#
M````!`````````(X`````````C@````````".``````````8`````````!@`
M````````"`````$````%````````````````````````````````````````
MGJP```````">K````````0```````0````8```````"?W````````9_<````
M```!G]P````````#M````````!04```````!```````"````!`````````-H
M`````````V@````````#:`````````(``````````@``````````"&1TY5$`
M```&````````````````````````````````````````````````````````
M```````09'3E4@````0```````"?W````````9_<```````!G]P`````````
M)``````````D``````````$`````````````````````````````````````
M````````````````````````````````````"````P`"```#````````````
M```!``````$H````````\@`#\@`````````````````````````````````"
M(%`!*````````+```````````````````````````````````````B!0`2@`
M``````"R#P`\``````````````````````````````````(@4`$H````````
M\O\'_``````````````````````````````````"(%`!*````````+,___P`
M`````````````````````````````````B!0`2@```````"R`P`,````````
M``````````````````````````(@4`$H````````L```````````````````
M```````````````````"(%```````````0````````,4``````````$`````
M```#'P`````````/````````!'(`````````#````````!>P``````````T`
M``````!>P``````````$````````!6@`````````!0```````!)P````````
M``8````````(F``````````*````````!)``````````"P`````````8````
M`'```#4```````&<2``````````5`````````````````````P```````:!@
M`````````!$````````7```````````2`````````(``````````$P``````
M```0`````'````$``````````0````!P```%``````````(`````<```!@``
M`````````````'````H`````````(`````!P```1`````````&D`````<```
M$@`````````9`````'```!,`````````)``````````8````````````````
M;___^P`````(```!````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````&$```!I````
M```````````4````4P``````````````8P``````````````*@```#<`````
M````/````%P````;`````````$4````"````"0```#,````?````"````#``
M``````````````````!6````(@```#H``````````````!,````D````1P``
M````````````'0```#4````I````4@`````````N````/0```#8````6````
M'@```"L`````````/@```!<`````````2````$(`````````30````\````E
M````9````"<``````````````$$`````````2@```%X````1````````````
M```O````.0````````!,````)@```#@````````````````````8````(P``
M`!4````@````&0```%<`````````+0````,````````````````````:````
M`````"P````2`````````&@````H````,0``````````````````````````
M````9P``````````````!@``````````````6P````````!A````````````
M``````````````````!=`````````$8```!9````$````$\```!4````````
M````````````#@````P`````````-````!P```!`````7P````L`````````
M(0```#\````R``````````<```!0``````````````!B````````````````
M````90```#L`````````#0``````````````0P```$D```!.````````````
M`````````````$L```!$````````````````````!0``````````````40``
M````````````9@```%4`````````````````````````6@```%@````*````
M`````````````````````&`````$````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````#```(````````%[``````````````
M`P42```)````````&0`````````"4```!!@0```)````````&0``````````
M````!!\2```)````````'0``````````2````VD2```)````````+K@`````
M````2````"H2```+````````7L``````````"````PLA````````````````
M`````````````U,2```)````````)N@````````!2```!"@2```)````````
M*#``````````&```!#D2```)````````'`@``````````````X02```)````
M````+P`````````!%````]P2```)````````,!0````````(E````[02```(
M````````%[``````````"`````$3`/_Q``````````$``````````````S42
M```)````````)A``````````6```!$42```)````````'```````````````
M!$T0```5```````!HY```````````````Y82```)````````+D0`````````
M=````ST2```)````````.*@````````##````[H2```)````````5NP`````
M```!P````PH1````````````````````````````!`(1```1```````!H$``
M````````"```!$82```)````````'````````````````_42```)````````
M*J0`````````+```!%,0```1```````!H```````````````!%H0```5````
M```!HY```````````````[$2```)````````5F0`````````B````^D2```)
M````````*M`````````!1````\\2```)````````+!0````````",````!(1
M```2```````!H%``````````````!&80```4```````!HY``````````````
M`Z02```)````````*$@````````"7````\42```)````````6*P````````"
M$```!&T0```5```````!L_``````````````!`P2```)````````.[0`````
M````K````+D2````````````7J```````````````,`2````````````7I``
M`````````````-$2````````````7H```````````````*\2````````````
M7G```````````````-@2````````````7F```````````````N$2````````
M````7E```````````````-\2````````````7D```````````````M,2````
M````````7C```````````````/,2````````````7B```````````````)P2
M`````````````````````````````?H2````````````7A``````````````
M`+02````````````7@```````````````/X2````````````7?``````````
M`````002````````````7>```````````````(L2````````````````````
M`````````'L2`````````````````````````````142````````````7=``
M`````````````&P2````````````7<```````````````1L2````````````
M7;```````````````2`2````````````7:```````````````3,@````````
M`````````````````````4T2````````````79```````````````&,2````
M````````78```````````````L,2````````````77```````````````5,2
M````````````76```````````````5@B````````````````````````````
M`6XB`````````````````````````````%02````````````75``````````
M`````7T1`````````````````````````````LL2````````````74``````
M`````````8\2````````````73```````````````PP1````````````````
M`````````````O@2````````````72```````````````$82````````````
M71```````````````WL2````````````70```````````````9@2````````
M````7/```````````````:82````````````7.```````````````:T2````
M````````7-```````````````#L2````````````7,```````````````;T1
M`````````````````````````````<@2````````````7+``````````````
M`<\2````````````7*```````````````MH2````````````7)``````````
M`````=0@`````````````````````````````?`2````````````7(``````
M`````````?D2````````````7'```````````````#`2````````````7&``
M`````````````?\2````````````7%```````````````@<2````````````
M7$```````````````2P2````````````7#```````````````@\2````````
M````7"```````````````A82````````````7!```````````````B(2````
M````````7````````````````ND2````````````6_```````````````KL2
M````````````6^```````````````BD2````````````6]``````````````
M`C`2````````````6\```````````````C<2````````````6[``````````
M`````CTB`````````````````````````````E42````````````6Z``````
M`````````FH2````````````6Y```````````````GL2````````````6X``
M`````````````H02````````````6W```````````````HL2````````````
M6V```````````````I<2````````````6U```````````````!P2````````
M````6T```````````````I\1`````````````````````````````JP1````
M`````````````````````````K,2````````````6S````````````!?1%E.
M04U)0U],24Y+24Y'`%]?4DQ$7TU!4`!097)L7W-Y<U]T97)M`%]F:6YI`'!E
M<FQ?<&%R<V4`<&5R;%]A;&QO8P!P97)L7V1E<W1R=6-T`%!E<FQ?<WES7VEN
M:70S`'!E<FQ?<G5N`'!E<FQ?8V]N<W1R=6-T`&)O;W1?1'EN84QO861E<@!0
M97)L7V%T9F]R:U]L;V-K`%!E<FQ?871F;W)K7W5N;&]C:P!P97)L7V9R964`
M9V5T=6ED`%]?<W1A8VM?8VAK7V9A:6P`<W1R;&5N`&UE;6-P>0!P=&AR96%D
M7V=E='-P96-I9FEC`%!E<FQ?;F5W6%,`;6MD:7(`7U]E<G)N;U]L;V-A=&EO
M;@!R;61I<@!R96%D`%!E<FQ?<V%F97-Y<VUA;&QO8P!?251-7W)E9VES=&5R
M5$U#;&]N951A8FQE`&-L;W-E`&5X:70`7U]R96=I<W1E<E]F<F%M95]I;F9O
M`%]?8WAA7V9I;F%L:7IE`%]?<W1A8VM?8VAK7V=U87)D`')E861L:6YK`%!E
M<FQ?<W9?<V5T<'8`<W1R8VAR`%!E<FQ?9W9?9F5T8VAP=@!03%]T:')?:V5Y
M`'-T<G-T<@!O<&5N`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!C;&]S
M961I<@!L<W1A=`!S=')N8VUP`&UE;6UO=F4`=6YL:6YK`%!E<FQ?;6=?<V5T
M`&UE;7-E=`!S=')C;7``9V5T<&ED`&QS965K`%]?9&5R96=I<W1E<E]F<F%M
M95]I;F9O`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?;F5W6%-?9FQA9W,`
M<VYP<FEN=&8`86-C97-S`%!E<FQ?9V5T7W-V`')E86QL;V,`4$Q?9&]?=6YD
M=6UP`'-T9&5R<@!O<&5N9&ER`')E861D:7(`9G!R:6YT9@!S=')N8W!Y`'-T
M<G1O:P!S=')D=7``<W!R:6YT9@!P=&AR96%D7V%T9F]R:P!?7VQI8F-?<W1A
M<G1?;6%I;@!?7V5N=FER;VX`;&EB<&5R;"YS;P!L:6)C+FUU<VPM;6EP<S8T
M+G-O+C$`>'-?:6YI=`!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V-U<G)E
M;G1?97AE8U]P<F]C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]S
M971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`<&%R7V9I;F1P<F]G`'-H85]I
M;FET`'-H85]U<&1A=&4`<VAA7V9I;F%L`'!A<E]I;FET7V5N=@!P87)?;6MT
M;7!D:7(`<&%R7V1I<FYA;64`<&%R7V)A<V5N86UE`&UY7W!A<E]P;`!P87)?
M8VQE86YU<`!?9G1E>'0`7W-T87)T7V,`<&%R7V-U<G)E;G1?97AE8P!?<W1A
M<G1?9&%T80!?7W-T87)T`%]F8G-S`%]F9&%T80!?7V)S<U]S=&%R=`!?961A
M=&$`7V5N9``O=7-R+VQI8B]P97)L-2]C;W)E7W!E<FPO0T]210``````````
M```````````````````!H``````````2`P```````:`(````````$@,`````
M``&@$````````!(#```````!H!@````````2`P```````:`@````````$@,`
M``````&@0````````!(#```````!HX@````````2`P``````````````````
M`````````````````````````````````````````````&>]_^#_O``0_[\`
M&``````$$0`!``````.`$"4\'``")YP(B`.?X"W?F8!H`R#X"0`````$$0`!
M``````.`$"4\'``")YP(9`.?X"W?F8#X`R#X"0````#?O``0W[\`&`/@``AG
MO0`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````&>]_[#_O`!`/!P``@.9X"UGG`=0WYF!Z/^E`!#_I@`(KZ0`
M'&>F``AGI0`09Z0`'/^_`$C_L``@_[,`./^R`#`#(/@)_[$`*-^&@5C?A(&`
MWYF"N`#`*"4#(/@)WY""2-^"@R"00@``%$``$]^9@4#?F8)``R#X"0``````
M0"`EWX*`.!2```3\1+/HWYF!T`,@^`DD!``!WYF!F`,@^`D`````WYF!0`,@
M^`F.!```H$`*C]^9@4`#(/@)C@0``(X$``"00P3BWYF!0#1C``(#(/@)H$,$
MXH^D`!R00P3B)(8``R2$``3?F8&H-&,``0`$(/B@0P3B`R#X"?^F``#?I0`0
M`$`X)=^"@#B/J``<_$>SX-RB``#?I@``_.(``-^"@%@``!@E9$)BN/SB``C?
M@H#HW$(``/SB`!#?@H!89$)BP/SB`!@``Q``9&,``21"``0``R````(0^`"(
M("H4@``V`.(0+=^1@#C?A8!8WYF"@-XDL^@``$`E9*4F:`,@^`G\0```%$``
M!0!`@"7?F8'``R#X"=XDL^@`0(`EWYF"&-XDL^@#(/@)WY.`6-^$@%AF<R`L
M`F#()0,@^`EDA&`@%$``#]^9@2C?DH`XWD*SV!1```7?A(!8`F#()0,@^`ED
MA%^H_D*SV-Y$L]@0@``#WYF`\`,@^`D`````WYF!*`,@^`G>)+/HWYF#&`,@
M^`D`````W[\`2-^\`$#?LP`XW[(`,-^Q`"@"`!`EW[``(`/@``AGO0!0``,@
M^`"D("W<A```$`#_O_Q$````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````01``<``/`E_______]^[C_______W\L/_______>,8
MW_P```/\X"\#H"`EW^4`$`"\*"W?^0`(`SS(+20!__`#H>@D`R#X"0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!G
MO?_P_[P``#P<``(#F>`M9YP#4-^9@A#?B(`@WX>`*(R%``1DA@`(WX2`,/^_
M``@#(/@)``!()=^_``C?O````^``"&>]`!```````````#P#``(`>1@M9&,#
M`-QD@#C<8H!`9(2@6!!$``7<>8)H$R```P`````#(``(``````/@``@`````
M/`,``@!Y&"UD8P+(W&2`.-QE@$!DA*!8`*0H+P`%$/L`!2_^`*(H+0`%*'L0
MH``%W'F!L!,@``,``````R``"``````#X``(``````````!GO?_0_[P`(#P<
M``(#F>`M9YP">/^S`!C?DX`X_[\`*))BHY#_L@`0_[$`"!1``"O_L```WX*!
MX!!```3?@H!(WYF!X`,@^`G<1```WX.`.-^1@%!D8Y_PWY"`.`(CB"_>`J.8
M`!&(^]^$@#AF,?__`%$8*V22G_`08``-WYF`6&1"``$```````(8^`)#&"W<
M>0```R#X"?X"HYC>`J.8`%$8*Q1@__AD0@`!WYF`6&<Y'5`#(/@)`````-^"
M@N`00``$WYF"X-^$@#@#(/@)9(2?W"0"``&B8J.0W[\`*-^\`"#?LP`8W[(`
M$-^Q``C?L````^``"&>]`#``````9[W_\/^\```\'``"`YG@+6><`7C?@H'8
M$$``!_^_``C?A8`XWX2`.-^9@=ADI:.@`R#X"62$G]S?F8!8W[\`"-^\``!G
M.1V(`R``"&>]`!```````````&>]_[#_O`!`/!P``@.9X"W_L0`0_[\`2/^V
M`#C_M0`P_[0`*/^S`"#_L@`8_[``"&><`2`0@``?``"()=^"@@C<5```$H``
M&P"`F"4`H*@E`(`P)20#`#V`P@``%$``(0#3@"\`$(```H"0)206`#W>40``
M$B``#]^9@H@"`#`E`F`H)0,@^`D"("`E%$``&0(P$"V`0@``%%8`%@`````"
M5)`O`!*0^V80``&NL@```C"(+=^_`$C?O`!`W[8`.-^U`##?M``HW[,`(-^R
M`!C?L``(`B`0)=^Q`!`#X``(9[T`4!!#_]\`````$`#_VF3&``$0`/_>9E(`
M"&>]_]#_O``@/!P``@.9X"UGG``D_[``&-^9@%C?D('P_[\`*-X"``!GI0`$
M9SD?,/^B``@#(/@)`````-^D``C>`P``$(,`!-^_`"C?F8$8`R#X"0````#?
MO``@W[``&`/@``AGO0`P9[W_L/^\`$`\'``"`YG@+6><_[S_L0`HWY&!\/^S
M`#C_L@`P_[``(/^_`$C>(@``WY"`6-^3@@C_H@`89[(`%&80'S`"0"@E`@#(
M)0,@^`G_I``(%$``"-^D``C?HP`8WB(``!!B``W?OP!(WYF!&`,@^`D`````
MCZ(`%``"&/C>8@```$,0+=Q#``@08/_M_$,``!``__QD0@`(W[P`0-^S`#C?
ML@`PW[$`*-^P`"`#X``(9[T`4&>]_L#_O`$P/!P``@.9X"UGG/\$_[4!&-^5
M@?#_OP$X_[<!*/^V`2#_M`$0_[,!"/^R`0#_L0#X_[``\-ZB``#_H@#H$(``
M&0````"`@@``$$``%@"`B"7?F8,P`R#X"0`````00``1`$"0)=^3@%C?E(!8
MWY:`6&9S7T!FE"%,WYF"P`,@^`D"0"`E%$``#M^9@LC?F8)P`R#X"0)`("7?
MF8&0`R#X"0(@("7?HP#HWJ(``!!B`#W?OP$XWYF!&`,@^`D`````9%``$P)@
M*"4#(/@)`@`@)1!`_^K?F8+`WYF"R&;%7T@#(/@)`@`@)1!`_^3?F8+`WYF!
M(`,@^`D"("`EWYF!(`(`("4#(/@)`$"X)=^9@I@"XA`M``(@``,@^`DDA``"
MWX6`6-^9@3@`0"`E`@`X)0(@,"5DI5]0`R#X"?^B``C?I``(WYF!8`,@^`EG
MI0`8)`/__Q!B``[?I``(CZ(`."0#0``P0O``%$,`"0`````"@,@E`R#X"0``
M``#?F8%H`R#X"=^D``@0`/^\WYF"P-^9@J`#(/@)_Z0`"!``__<`````W[P!
M,-^W`2C?M@$@W[4!&-^T`1#?LP$(W[(!`-^Q`/C?L`#P`^``"&>]`4!GO?\`
M_[P`\#P<``(#F>`M9YS]+/^Q`.C?D8'P_[``X-^9@GC_OP#XWB(``&>E``@`
M@(`E_Z(`V`,@^`D`````%$``%(^C`"@D!4``,&/P`!!E``0`8"`E-`.@`!2#
M``8`````WYF#`"0%``(#(/@)`@`@)2Q"``'?I`#8WB,``!"#``;?OP#XWYF!
M&`,@^`D`````$`#_^```$"7?O`#PW[$`Z-^P`.`#X``(9[T!`&>]_Z#_O`!0
M/!P``@.9X"UGG/Q\_[,`,-^3@?#_L0`@_[``&/^_`%C_M@!(_[4`0/^T`#C_
ML@`HWF(``("C``#_H@`()`(`/0"`B"448@`"`*"`)62P``'?F8$@`R#X"0(`
M("7?F8!89Z4`!`(@("5G.1\P`R#X"0!`H"400``3`$"0)=^9@2`#(/@)`$`@
M)0!4$"L40``F`B`8)8("``!F$``!9E(``11`__RB0O__WZ,`"-YB```08@!6
MW[\`6-^9@1@#(/@)`````-^5@@@``)`EWK8```+`$"7<0P``%&``/&1"``C?
M@H`X)D0``HQ#L]`08``Y``0@^-^9@Q``@"@E`R#X"0+`("400/_H_J(``"9"
M``$``ACXWJ(```!#$"W\0```K[(`!`(@&"4D!``]@&(``!!```./L@`$%$0`
M,@````#?E8((`'$8+]^9@I@``Q@`9H0``@`2$/@`9"`MWK(```,@^`D"0I`M
M$$#_S_Y"``"/H@`$)`4`/0`"&/C>H@```$,0+=Q"``""(P``9C$``:!#````
M0"`E$&```V1"``$49?_Y`````"0#`#V@@P``@@,``&80``%D0@`!%&#__*!#
M__\0`/^X`````!``_\$F4@`!WYF"F"0#``$#(/@)K$.ST!!`_[``0"`EWYF"
MD``2,/@#(/@)`L`H)1``_\/^H@``$`#_R61C``'?O`!0W[8`2-^U`$#?M``X
MW[,`,-^R`"C?L0`@W[``&`/@``AGO0!@9[W_\/^\```\'``"`YG@+6><^D#?
M@H)(_[\`"-^9@4`#(/@)C$0``-^'@'#?A8!8WX:!B-^9@5!DYYYX9*5?6`,@
M^`D`0"`EW[\`"-^\```#X``(9[T`$&>]_^#_O``0/!P``@.9X"UGG/GH_[``
M"-^0@DC_OP`8WYF!0`,@^`F.!```WYF`>`,@^`D`0"`EWYF!0`,@^`F.!```
MWXB`6-^%@%C?AH"`WYF"\&4(8K```$@E`0`X)62E7W@#(/@)`$`@)=^_`!C?
MO``0W[``"`/@``AGO0`@9[W?H/^\(%`\'``"`YG@+6><^6C_LR!(WY.!\-^9
M@M#_OR!8_[(@0/^Q(#C_L"`PWF(``/^B("@#(/@)`````-^(@%C?AH!8WYF"
M^&>D`!AE"%^0`$`X)63&7Y@D!1`!`R#X"?^D``@D`___%$,`"=^D``@``"`E
MWZ,@*-YB```08@`IW[\@6-^9@1@#(/@)`````"Q#$`$$;```!$#_]=^9@@!G
ML1`@)`80``,@^`D"("@E``*```8`_^X"`)`EWYF"F`,@^`DF!``!$$#_Z0!`
M("4`41`K$$``!`(D$"L`DA`M`B(`,P(D$"L00``$WYF!,`(P$"T`@@`SWYF!
M,`(`,"4"("@E*E(0`@9,```#(/@)``````!0@"T`0"`E$`#_U:(```#?O"!0
MW[,@2-^R($#?L2`XW[`@,`"`$"4#X``(9[T@8#P#``(`>1@M9&/X(-QY@(@#
M(``(`````&>][K#_O!$X/!P``@.9X"UGG/@(_[<1,/^P$/C?EX'P`("`)=^9
M@%C?A(!8_[\12/^T$1C_LQ$0_[X10/^V$2C_M1$@_[(1"/^Q$0#>X@``9(1?
MJ&<Y("P`H)@E_Z(0Z`,@^`D`````WYF","0%`"\"`"`E`R#X"0!`H"400``.
MWYF!(-^$@%C?F8!8`@`H)6<Y(]0#(/@)9(1?N-^C$.C>X@``$&(`8-^_$4C?
MF8$8`R#X"0`````"`"`E`R#X"=^2@%C?F8%(9D5?R`)@("4#(/@)``*(`-^5
M@%C?EH!8`$#P)=^"@%AFM5]`9M9?T/^B``@3P/_DWX2`6(/"```40``"````
M``*@\"42@``,WYF"R`/`*"4#(/@)`H`@)11```C?F8$@WYF!2&9%7\@#(/@)
M```@)1``_^X`0/`EWYF!(`,@^`D#P"`E)`0`+P`"$``D0___`\,8+8!E```0
MI``4)$;__R8C``$`8A`A*$(0`!!`_\/?H@`(WYF"^&>S`.@"`$@E`L!`)0/`
M."5D1E_8)`40``,@^`D"8"`E)$(``2Q"$`$40``%WYF!8````#2@8```$`#_
MY@#`$"5GI0`8`R#X"0)@("440/_6CZ(`.#0#@``P0O``%$/_T]^9@4C?F8,`
M)`4``0,@^`D"8"`E%$#_S=^9@4C?A(!8WYF`6`)@*"5G.2/4`R#X"62$7[C?
MF8)@`R#X"0)@("40`/^>`$"`)=^^$4#?O!$XW[<1,-^V$2C?M1$@W[01&-^S
M$1#?LA$(W[$1``(`$"7?L!#X`^``"&>]$5``@!`E)`4`+X"#```48``#````
M``/@``@`````%&7_^F2$``$0`/_X`(`0)6>]_^#_O``0/!P``@.9X"W_OP`8
M_[``"!"```1GG/6`@((``!1```L`@(`EWX2`6-^9@F!DA%]``R#X"0````#?
MOP`8W[P`$-^P``@#X``(9[T`(-^9@2`#(/@)`````"0#`"]D0O__`@(0+0("
M("L0@``H`````(!$```0@P`A`````"0#`"\"`B`K$(``(0````"`1```%(,`
M'&1%__\D`P`O9$+__P("("L0@``&`%`P+X!$```0@__[9$+__V1"``$`4#`O
M9,,``BQC$`$08/_;```0)0(`*"7?D(`XWYF!^&3&``%F!*/0+,(0`01,```#
M(/@)`````!``_]!F`J/0$`#_V61"__\0`/_>`*`0)18"_^,D`P`O@@,``"0"
M`"\48@`$WYF"8-^$@%@0`/_!9(1?0-^$@%@0`/^^9(1?T&>]_X#_O`!P/!P`
M`@.9X"UGG/0\_[4`8-^%@'#?E8'P_[\`>-^9@3#_M@!H_[0`6/^S`%#_L@!(
M_[$`0/^P`#@D!@`B9*6>4-ZB```#H"`EWY"`6/^B`"@#(/@)9A`@E-^$@%@"
M`,@E9(1?X`,@^`G?DX!8WX2`6`(`R"5DA%_P`R#X"=^4@%C?A(!8`@#()62$
M7_@#(/@)WY*`6-^$@%@"`,@E9(1@"`,@^`G?EH!8`@#()69D8!`#(/@)WY&`
M6-^$@%@"`,@E9(1@(`,@^`EF,2`L`@#()0,@^`EFA%^H`@#()0,@^`EF1&`P
M`@#()0,@^`EFQ&!`WX2`6`(`R"4#(/@)9(1@4-^$@%@"`,@E9(1?N`,@^`G?
MD(!8WX2`6`(@R"5DA&!@`R#X"680(]000``$`@#()0!`*"4#(/@)9L1@0-^$
M@%@"(,@E`R#X"62$8'@00``%`$`H)=^$@%@"`,@E`R#X"62$7Q#?A(!8`B#(
M)0,@^`EDA&"09H1?J!1```@`0"@EWX2`6`(@R"4#(/@)9(1@H!!``!$`0"@E
M9D1@,`(`R"4#(/@)`````-^%@%AF9&`0`@#()0,@^`EDI6#(WZ,`*-ZB```0
M8@`.W[\`>-^9@1@#(/@)`````-^%@%C?F8*()`8`"F2E8+@#(/@)9Z0`$11`
M_^UGI0`;$`#_Z&9$8##?O`!PW[8`:-^U`&#?M`!8W[,`4-^R`$C?L0!`W[``
M.`/@``AGO0"`9[W_X/^\`!`\'``"`YG@+6><\@S_L``(WY"`."0"__^.`Z`P
M%&(`#?^_`!C?A(!8WYF`6&<Y("P#(/@)9(1@,!!```4``!@E@$(``!!```(X
M0@`P``(8*ZX#H##?OP`8C@*@,-^\`!#?L``(`^``"&>]`"!GO?_P_[P``#P<
M``(#F>`M9YSQF-^9@1#_OP`(`R#X"0````#?F8(@`R#X"0!`("400``"W[\`
M"-Q"``#?O````^``"&>]`!!GO?_0_[P`(#P<``(#F>`M9YSQ4/^S`!C?F8!8
MWY.`6/^Q``AG.2`L`("()69D8-#_OP`H_[(`$`,@^`G_L````F`@)1!```4"
M("@E`$"`)8!"```40``,WYF"4&2$8-#?F8!8W[\`*-^\`"#?LP`8W[(`$-^Q
M``C?L```9SDCU`,@``AGO0`P`R#X"0(`("440``9W[\`*-^9@2`#(/@)`B`@
M)=^9@2`"`"`E`R#X"0!`D"7?F8*8`D(0+0,@^`ED1``"WX>`6-^%@%C?F8$X
M9*5?V`!`("4"`$`E9.=?R`(@,"4#(/@)`$"0)0)`*"40`/_;9F1@T-^\`"#?
MLP`8W[(`$-^Q``C?L````^``"&>]`#!GO8`0_[Q_V#P<``(#F>`M9YSP//^W
M?]#?EX'P_[]_Z/^V?\C_M7_`_[1_N/^P?YC_OG_@_[-_L/^R?ZC_L7^@9[W^
M``"`J"5GI``0WN(``#0#@7@`9!@M_&(``#P0__\T`H&``%`0+0!$@"W?@H!8
MWX6`.&1"8.C^`GZ`WX*`6-^9@3!D0E]`)`8`,&2EH`!F!'ZP_@)^B`,@^`G^
M`'Z0WX*`6-^6@%AD0F#P_@)^F-^4@%C?@H!89M8@+&1"8/AFA%^H`L#()?X"
M?J`#(/@)_@!^J!!``!;?F8"0`$"`)8!"```00``2`````-^9@)@#(/@)`@`@
M)=^9@F`#(/@)`@`@)0!`@"5GHP`0-`*!>`!#$"W<0P``WN(``!!B`<\"`!`E
MWYF!&`,@^`D``````R#X"0`````40``:`$"`)3P1__]F,7Z8-`*!@`!1$"UG
MHP`0`$.(+=XD```4@``$`L#()=^0@%@0```.9A!@X`,@^`D`````%$```P!`
M("40`/_U9C$`"(!"```00/_\WYF"8`,@^`D`````$$#_^`!`@"7?F8$@`@`@
M)0,@^`G?DX!8WYF"F``"('ADA``!`R#X"69S80@`0)`E`$"()8(&```4P`!:
MWYF!.#P1__]F,7ZPWY.`6#0"@8``41`M9Z,`$`!#B"UF<R,DWC```!(``!`"
MP,@E`R#X"0(`("400`!2`$"`)8!"```00`!/`F#()0,@^`D"`"`E$$#_\V8Q
M``C?F8)@`R#X"0(`("4`0(`E/!'__V8Q?H#?GH!8-`*!@`!1$"UGHP`0`$.(
M+6?>(R06```(WYF!(-XS```28``%`````()B```40``Y`\#()=^9@2`#(/@)
M`@`@)=^9@2`"0"`E`R#X"0!`B"7?F8*8`B(@+0`$(``DG@0$`R#X"0/`("4"
M0$@EWXB`6-^2@%C?A8!8WYF!.&4(81!F1U_0`@`P)62E81@`0"`E`R#X"0!`
MB"7?F8%P)`4!P`,@^`D"("`E)`/__Q1B`"+?F8%X`R#X"0````",2```)`(`
M$1$"`!S?@H,HWX6`6-ZF``#<1```WYF!R`(@."4#(/@)9*5A*!``_W,``(`E
M`B`@)3#&`/\"8"@E`R#X"680``$0`/^>9C$``A``_Z=F,0`(`R#X"0)@("40
M0``$WYF"8`,@^`D"8"`E`$"`)1``_[AF,0`(/!#__V8%?N`T`H&`WYF">`!%
M$"UGHP`0`$,H+0,@^`D"("`E$$``"P!`F"7?@H,HWX6`6-ZF``#<1```WYF!
MR`(@."4#(/@)9*5A:!``_]@`````-`*!@`!0$"UGHP`0`$.`+8X"?P`D`T``
M,$+P`!1#_^_?@H,HWYF!$(X#?P@#(/@)_Z,`"-^C``@``A``%&+_Y]^"@RB.
M`G\`)`,!P#!"`?\40__BWX*#*-^9@I@#(/@)`\`@)=^$@%@"P,@E9(1AP`,@
M^`D`0(`E%$``?P!`("7>M@``WYF!(`,@^`D"P"`E``(0``!`\"4H0@`$%$``
M(]^9@*#?A8!8WYF"R&?$__QDI6'(`R#X"0+$("T40``;WYF`H"0"``03P@`&
M)][_^P+>\"V#PP``)`(`+Q1B`!,`````WK4`"!*@``_?F8$@`R#X"0*@("4L
M0P`$%&``"]^9@*#?A8!8WYF"R&1"__QDI6'0`R#X"0*B("T40``#WYF`H`*@
ML"7?F8"@`R#X"0`````40`"BWX6`6-^9@E@``"@E`R#X"0+`("400`";`$"H
M)=^9@M@D!@`")`7_[@!`("4#(/@)/!/__V9V?_@T`H&`9Z,`$`!6$"T`0[`M
MWYF!H"0&``8"P"@E`R#X"0*@("4T`H&`9Z,`$`!3$"T`0Q`MD$-_^!1@`#[?
MF8+8D$-_^20$`$,49``[```P)9!%?_HD!`!!%*0`-P````"01'_[%(,`-"0#
M`$B01'_\%(,`,@``*"600W_])`(`111B`"X`````)`8``B0%_\8#(/@)`J`@
M)=^9@:`D!@`I`L`H)0,@^`D"H"`EWXF`6`+`0"5E*6*PWX6`6-^9@3AF1U_0
M`B`P)62E8=@#(/@)`@`@)=^9@6@#(/@)`B`@)=^9@%@"`"@E9SDCU`,@^`EF
MA%^HWYF`F`,@^`D"`"`E$`#^KV>C`!#?F8)@`R#X"=ZV``#?F8"H`L`@)0,@
M^`D`0"@E%$#_>P!`L"40`/]YWK8`````,"4``"@E`J`@)0,@^`D\$___WYF`
ML`,@^`EF?G_X9Z,`$`!`L"4T`H&``%X0+0!#\"W?F8&@-`:```/`*"4#(/@)
M`J`@)0`",``<P``MWYF`N-^9@;@"H"`E`R#X"69S?[`T`H&``%,0+6>C`!``
M0Z@MWYF`P`+`*"4"H"`E`R#X"69S`!C?A8!8-`*!@`!3$"UGHP`0`$.8+0``
M\"4\%O__9*5A"`*^$"W?F8$XD$8```)@("7_I0`(`R#X"6?>``$D`P`4WZ4`
M"!?#__9F<P`"-`*!@&>C`!``5A`M`$,0+6;(?\C?B8!8H$!_\#0"@8``2!`M
M92EBL!``_Z$`0T`M`\`H)0,@^`D"P"`E$`#_R=^9@:#?A8!8WX2`6-^9@%AD
MI6#(9(1@,&<Y(]0#(/@)WY6`6-^9@M#?EH!8`R#X"20>___?A8!8WYF!.&:I
M8K``0$`E9D=?T`(@,"5DI6'H`@`@)6:U8K`#(/@)9M9A^-^9@7`D!0'``R#X
M"0(`("47PO^&WYF!>`,@^`D`````)`,`$8Q"```40_^`WYF"T`,@^`D`````
MWYF!."9I``$"H%`E`$!`)69'7]`"(#`E`L`H)0(`("4#(/@)`2"8)1``_^C?
MF8%P9[T"`-^_?^C?OG_@W[Q_V-^W?]#?MG_(W[5_P-^T?[C?LW^PW[)_J-^Q
M?Z#?L'^8`^``"&>]?_!GO?_0_[P`(#P<``(#F>`M9YSGJ/^P``#?D()(_[\`
M*/^R`!#_L0`(_[,`&-^9@4".!````R#X"=^2@%B.!```WYF!0`!`B"4#(/@)
M9E(@+-^$@%B2(P"P9(1@$`)`R"4#(/@)H$,`L1!```<D`P`Q@$0``!2#``7?
MF8#(@$(``1!```7?F8%`WYF`R`,@^`D`````WYF!0`,@^`F.!```WX6`6-^9
M@C@D!P`#)`8``62E8A`#(/@)`$`@)1!``!D`0(@EWYF!0`,@^`F.!```WB,`
M$-^&@%C<90``WYF"*`!`("4#(/@)9,9B&-XB`!#<0@``C$(`#``"%8(P0@`!
M$$``"=^9@4`#(/@)C@0``-XC`!#?F8*HW&4```,@^`D`0"`EWYF!0`,@^`F.
M!```WX6`6-^9@C@D!P`#)`8``62E8B`#(/@)`$`@)1!``"0`0(@EWX2`6`)`
MR"4#(/@)9(1?N!!```P`0)@EWYF!0`,@^`F.!```WB,`$`)@,"7<90``WYF"
M*`,@^`D`0"`E$```$P````#?F8"(`R#X"0````".!```WYF!0!!``#4`0)@E
M`R#X"0````#>(P`0WYF"*-QE````0"`E`R#X"0)@,"7?F8%H`R#X"0)@("7?
MF8%``R#X"8X$``".!```WYF!0`,@^`D`0(@EWX6`6-^9@P@D!@`!9*5B*`,@
M^`D`0"`EWX:`6-^9@BADQF)``$`H)0,@^`D"("`EC@0``-^9@4`#(/@)WY"`
M.-^$@%@"0,@E9(1?J`,@^`F@0`"Q`@"()11``!+^`K/8WX*`.-^9@-`#(/@)
MW$2SX!1```S^`K/8WX2`6-^9@N@#(/@)9(1B2`,@^`D`````WX.`.-QDL^#>
M(P`0$`#_N=R&``#?F8%PWB2SV`,@^`DD!0'``$`X)20"`!$0X@`,).(``2Q"
M``(40``*W[\`*-^"@#C?A(!8W$*SX-XFL]C<10``WYF"Z`,@^`EDA&)PW[\`
M*-^\`"#?LP`8W[(`$-^Q``C?L````^``"&>]`#!GO?_@_[P`$#P<``(#F>`M
M9YSDG-^9@-C_OP`8_[$`"/^P```#(/@)`("`)=^9@.`#(/@)`$`@)=^9@*`#
M(/@)`$"()1!``!3?OP`8$@``$@````""`@``$$``#]^%@%C?F8)09*5A$`,@
M^`D"("`E%B(`"=^_`!C?F8!8W[P`$-^Q``@"`"`EW[```&<Y(4P#(``(9[T`
M(-^\`!#?L0`(W[````/@``AGO0`@9[W]0/^\`K`\'``"`YG@+6><X_#?BH'P
M_[\"N/^S`JC_L@*@_[$"F/^P`I#=0@``9(,`./^B`HAGH@`(9(<`>`!`*"7<
M9@``9&,`"``&0#X`!C`\``8P/ORH``#\I@`(%./_^&2E`!!D1@(`W$4`0-Q#
M`&AD0@`(`&48)MQ%``@`91@FW$7_^`!E&"8``RAX``,?^@"C&"4``Q@\``,8
M/A1&__+\0P!XW(P``#P-6H(`#![Z``P1>`!#$"7?HP`(9:UYF=R+`"#<AP`0
MW(@`&`!M&"T``A`\W(D`"`!K&"T``A`^`$,0+0#H&"8`:1@D`&@8)@!#$"T`
M"3>X``D8N@##,"4`!H`\`!"`/M^C`!``\,`F`PS`)`!M&"T``A`\``(0/@,'
MP"8`:!@M`P/`+0`"*7@``A[Z`*,H)0,%P"T`#!BZ``PON`"C*"4`Q7`FWZ8`
M&`'"<"0`S3`M`!C`/``8P#X`QS`M`=!P)@'&<"T`&!EX`!@V^@!F&"4!PW`M
M``(?N``"$+H`8A`E`*(8)@`%R#S?I0`@``YP/``.<#X`K2@M`!G(/@!X&"0`
ML(`M``XV^@!Y&"8`#BEX`*8H)0!P&"T`91@M`!@ON``8P+H`N"@EW[@`*``"
M>#P`11`F`PW`+0`/>#X`3A`D``,8/``#&#X#&<@M`$\0)@!9$"T``\%X``/.
M^@,9P"4`#H>X``YPN@(.@"4`6!`MW[@`,``%,#P`L"@F`PW`+0`&,#X`HR@D
M``(0/``"$#X##W@M`*8H)@`"QOH`KR@M``)Y>`'X>"4`KR@M``//N``#>+H#
M+\@EW[@`.`(9&"8`$'`\`PW`+0`.<#X`8A@D``4H/``%*#X#!C`M`&X8)@`%
MQOH`9A@M``4Q>`#8,"4`9A@M``+'N``",+H#!L`E`S@0)@`9>#S?N0!```]X
M/@,MR"T`11`D``,8/``#&#X#+G`M`$\0)@`#SOH`3A`M``-Q>`'9<"4`3A`M
M``7/N``%<+H#+L@E`QDH)@`8,#S?N`!(``8P/@,-P"T`HR@D``(0/``"$#X#
M#W@M`*8H)@`"QOH`KR@M``)Y>`'X>"4`KR@M``/'N``#>+H##\`E`S@8)@`9
M<#S?N0!0``YP/@,MR"T`8A@D``4H/``%*#X#)C`M`&X8)@`%SOH`9A@M``4Q
M>`#9,"4`9A@M``+/N``",+H#)C`E`P80)@`8>#S?N`!8``]X/@,-P"T`11`D
M``,8/``#&#X##G`M`$\0)@`#QOH`3A`M``-Q>`'8<"4`3A`M``5WN``%*+H!
MQ7`EWZ4`8``&@#P`SC`F`*TH+0`0@#X`PS`D``(0/``"$#X`KW@M`-`P)@#/
M,"T``BEX``)^^@"O*"4``\^X``,8N@,CR"4`Q3`MWZ,`:``.P#P`!C`\`=EP
M)@`&,#X`;1@M`!C`/@'"<"0`<(`M``8N^@'8<"8`!AEX`&48)0'0<"T!PW`M
M``(?N``"$+H`8A`EWZ,`<``9>#P`#G`\`R+()@`.<#X`;1@M``]X/@,FR"0`
M>,`M``XN^@,OR"8`#AEX`&48)0,XR"T#(\@M``8HN@`&'[@`92@E`$4P)@`"
M@#S?H@!X`!G(/``9R#X`31`M`!"`/@#.,"0`3W@M`!D>^@#0,"8`&1%X`$,0
M)0#/,"T`#A^X``YPN@!N&"4`PC`MWZ(`@``%P#P`!C`\`*,H)@`&,#X`31`M
M`!C`/@"Y*"0`4(`M``9V^@"X*"8`!A%X`$X0)0"P*"T`HB@M`!D7N``9R+H`
M61`EWZX`B``#>#P`8A@F`<UP+0`/>#X`9A@D``4H/``%*#X!V,`M`&\8)@!X
M&"T`!7%X``7&^@'8<"4`;A@M``9WN``&,+H!QC`EW[@`D``"@#P`1A`F`PW`
M+0`0@#X`11`D``,8/``#&#X##W@M`%`0)@`#QOH`3Q`M``-Y>`'X>"4`3Q`M
M``5_N``%*+H!Y2@EWZ\`F``"$#P``A`^`>UX+0'P@"T`!G`\``)^^@#%,"8`
M`L%X``YP/@##,"0##\`E`,XP)@`#?[@`&,`\``,8N@'C&"4`T#`MWZ\`H``8
MP#X`V#`M``60/`"C*"8`$I`^``;(/`"B*"0![6@M`!G(/@"R*"8!KF@M`*UH
M+0`9=OH`&2EX`*XH)0`%*#P`!2@^`:5H+0`"+[@``A"Z`*(0)0!BP"8#!L`F
M/`5NV=^F`*@TI>NA``V8/``3F#X`Q3`M`-*0+0`3=OK?KP"P`!,Q>`#.,"4`
M&8^X`!C`/``9R+H``Q@\`CF()0'E>"T``Q@^`!C`/@`&,#P#$L`M``8P/@'C
M>"T`41@F`P;`+0!M:"8`&)`\``UH/``2D#X`#6@^`!(>^@'M>"T`$FEX`:-H
M)0`-:#S?I@"X``UH/@'M>"T`$\^X``(0/``3F+H#,\@E``^`/`#%,"T``A`^
M`!"`/@#","T".1`F`%C`)@`0<7@`$!;Z`<)P)0`8P#P`&,`^``YP/`#8,"T`
M#G`^`,XP+0`2Q[@`$I"Z`Q+`)0`&F#P`$Y@^`S@0)M^M`,``3W@F`!,9>``3
M%OH`$8@\`:5H+0`1B#X`8A@E``]X/`&Q:"T`#W@^``,8/`&O:"T``Q@^`:-H
M+0`0C[@`$("Z`C"()0`-D#P`$I`^`Q$0)M^N`,@`$A[Z`$8P)@`9R#P`$A%X
M`<5P+0`9R#X`0Q`E``8P/`'9<"T`!C`^``(0/`'&<"T``A`^`<)P+0`3S[@`
M$YBZ`S/()0`.@#P`$(`^`CD0)M^C`-``36@F`!`Q>``0%OH`&,`\`&48+0`8
MP#X`PC`E``UH/`!X&"T`#6@^``8P/`!M&"T`!C`^`&88+0`2?[@`$I"Z`?)X
M)0`#P#P`&,`^`R\P)M^B`-@`SG`F`!AI>``8-OH`$8@\`$40+0`1B#X!IF@E
M``YP/`!1$"T`#G`^`!"/N``-:#P`$("Z`C"()0!.$"T`#6@^WZ8`X`!-$"T!
M\6@F`:,8)@`9R#P``I`\`,4P+0`9R#X``Q@\`!*0/@#9,"T``Q@^`,,P+0`2
M<7@`$A[Z`<-P)0`8S[@`&,"Z`SC()0`.<#P".1@FWZT`Z``.<#X`SC`M`&(0
M)@`/>#P`!H`\`:5H+0`/>#X``A`\`!"`/@&O:"T``A`^`:)H+0`0&7@`$!;Z
M`&(8)0`#&#P``Q@^`:-H+0`2?[@`$I"Z`?)X)0`-P#P`&,`^`R\0)M^N`/``
M&![Z`$8P)@`1B#P`&!%X`<5P+0`1B#X`0Q`E``8P/`'1<"T`!C`^``(0/`'&
M<"T``A`^`<)P+0`0C[@`$("Z`C"()0`.D#P`$I`^`?$0)M^C`/@`36@F`!(Q
M>``2%OH`&<@\`&48+0`9R#X`PC`E``UH/`!Y&"T`#6@^``8P/`!M&"T`!C`^
M`&88+0`8A[@`&,"Z`AB`)0`#F#P`$Y@^`C`P)M^B`0``SG`F`!-I>``3-OH`
M#W@\`$40+0`/>#X!IF@E``YP/`!/$"T`#G`^`!)_N``-:#P`$I"Z`?)X)0!.
M$"T`#6@^`$T0+=^F`0@"#V@F`:,8)@`1B#P``L@\`,4P+0`1B#X``Q@\`!G(
M/@#1,"T``Q@^`,,P+0`9P7@`&1[Z`P/`)0`3C[@`$YBZ`C.()0`8P#P!\1@F
MWZT!$``8P#X`V#`M`&(0)@`0@#P`!I`\`:5H+0`0@#X``A`\`!*0/@&P:"T`
M`A`^`:)H+0`2&7@`$A;Z`&(8)0`#&#P``Q@^`:-H+0`9A[@`&<BZ`AF`)0`-
MF#P`$Y@^`C`0)M^X`1@`1C`F`!-Q>``3%OH`#W@\`P7`+0`/>#X!PG`E``8P
M/`,/P"T`!C`^``YP/`,&P"T`#G`^`P[`+0`2?[@`$I"Z`?)X)0`8R#P`&<@^
M`@\0)M^C`2``36@F`!DQ>``9%OH`$8@\`&48+0`1B#X`PC`E``UH/`!Q&"T`
M#6@^``8P/`!M&"T`!C`^`&88+0`3C[@`$YBZ`C.()0`#D#P`$I`^`?$0)M^N
M`2@`$C;Z`%C`)@`0@#P`$A%X`<5P+0`0@#X`1A`E`!C`/`'0<"T`&,`^`!F'
MN``"$#P`&<BZ`AF`)0'8<"T``A`^`<)P+=^F`3`",!`F`$,8)@`/>#P`#L`\
M`,4P+0`/>#X``Q@\`!C`/@#/,"T``Q@^`,,P+0`8$7@`&![Z`$,0)0`2?[@`
M`A`\`!*0N@'R>"4``A`^`@\8)@#","W?H@$X``;(/`!N<"8`$8@\`!G(/@!%
M$"T`$8@^``YP/``9;OH`41`M``YP/@`9&7@`;1@E`$X0+0!#$"T``G`\`!B/
MN-^B`4``&,"Z`CB()0!%*"T!\1`F`$8P)@`0@#P`#G`^`!"`/@`&,#P`#A[Z
M`+`H+0`&,#X`#A%X`$,0)0"F*"T`&1^X`!G(N@!Y&"4`HB@M/`(CQM^F`4@`
M`\@\-$+O-P`"$+@`&<@^`B-H)0`/>#P`PC`M`!'`/`&N:"0".8@D``4H/``/
M>#X`!2@^`,]X+0&Q:"4!KV@M``4Q>``%?OH`SS`E`:9H+0`.-[@`#G"Z`,YP
M)0!N&"4!V3`D`&48)`!F&"7?I@%0`!C`/@#","T`#6@\``UH/@#8P"T`>!@M
M``TQ>``-QOH`V#`E`&88+0`%-[@`!2BZ`,4H)0`%P#P`&,`^`<4P)0`.>#P`
MS3`D`=AP)`#.,"7?K@%8``,8/`'"<"T``Q@^`=G(+0#9,"T``W%X``/.^@'9
M<"4`#<^X``UHN@,MR"4`N2@E`SAH)`"C*"0`K2@EWZT!8`#.,"T!HF@M``]X
M/@`&,#P`!C`^`:]X+0"O*"T`!FEX``9^^@&O:"4`K2@M``-ON``#&+H!HQ@E
M``-X/``/>#X#(V@E`!EP/`&F:"0#+\@D`;EH)=^Y`6@`!2@\`R+(+0`%*#X#
M.,`M`;AH+0`%SOH`!<%X`QG`)0`&S[@`!C"Z`R;()0!Y&"4#+S`D`&48)`!F
M&"7?I@%P`;AH+0#","T`#G`^``UH/``-:#X`SG`M`&X8+0`-,7@`#7;Z`,XP
M)0!F&"T`!3>X``4HN@#%*"4`!7`\``YP/@,E,"4`&<`\`,TP)`,NR"0`V3`E
MW[D!>``#&#P#(L@M``,8/@,O>"T`SS`M``/.^@`#>7@!^7@E``W/N``-:+H#
M+<@E`+DH)0,N:"0`HR@D`*TH)=^M`8``SS`M`:)H+0`8P#X`!C`\``8P/@&X
MP"T`N"@M``9I>``&QOH!N&@E`*TH+0`#;[@``QBZ`:,8)0`#P#P`&,`^`R-H
M)0`9>#P!IF@D`SC()`&Y:"7?N0&(``4H/`,BR"T`!2@^`RYP+0&N:"T`!<[Z
M``5Q>`'9<"4`!L^X``8PN@,FR"4`>1@E`S@P)`!E&"0`9A@EWZ8!D`&N:"T`
MPC`M``]X/@`-:#P`#6@^`,]X+0!O&"T`#3%X``U^^@#/,"4`9A@M``4WN``%
M*+H`Q2@E``5X/``/>#X#)3`E`!EP/`#-,"0#+\@D`-DP)=^Y`9@``Q@\`R+(
M+0`#&#X#.,`M`-@P+0`#SOH``\%X`QG`)0`-S[@`#6BZ`RW()0"Y*"4#+V@D
M`*,H)`"M*"7?K0&@`-@P+0&B:"T`#G`^``8P/``&,#X!KG`M`*XH+0`&:7@`
M!G;Z`:YH)0"M*"T``V^X``,8N@&C&"4``W`\``YP/@,C:"4`&<`\`:9H)`,N
MR"0!N6@EW[D!J``%*#P#(L@M``4H/@,O>"T!KV@M``7.^@`%>7@!^7@E``;/
MN``&,+H#)L@E`'D8)0,N,"0`91@D`&88)=^F`;`!KV@M`,(P+0`8P#X`#6@\
M``UH/@#8P"T`>!@M``TQ>``-QOH`V#`E`&88+0`%-[@`!2BZ`,4H)0`%P#P`
M&,`^`R4P)0`9>#P`S3`D`SC()`#9,"7?N0&X``,8/`,BR"T``Q@^`RYP+0#.
M,"T``\[Z``-Q>`'9<"4`#<^X``UHN@,MR"4`N2@E`SAH)`"C*"0`K2@EWZT!
MP`#.,"T!HF@M``]X/@`&,#P`!C`^`:]X+0"O*"T`!FEX``9^^@&O:"4`K2@M
M``-ON``#&+H!HQ@E``-X/``/>#X#(V@E`!EP/`&F:"0#+\@D`;EH)=^Y`<@`
M!2@\`R+(+0`%*#X#.,`M`;AH+0`%SOH`!<%X`QG`)0`&S[@`!C"Z`R;()0!Y
M&"4#+S`D`&48)`!F&"7?I@'0`;AH+0#","T`#G`^``UH/``-:#X`SG`M`&X8
M+0`-,7@`#7;Z`,XP)0!F&"T`!3>X``4HN@#%,"4`!H`\`!"`/@,F*"4#,'`D
M`*TH)`"N*"7?K@'8``,8/`'"<"T``Q@^`<]X+0"O>"T``W;Z``,I>`"N*"4`
M!2@\``4H/@'E>"T`#2^X``UHN@"M:"4`S3`E`;`H)``9P#P`PS`D``_(/``9
MR#X`Q3`EWZ4!X``9GOH`&7%X`!C`/@"B$"T!TW`E`%@0+0`.<#P`PA`M``YP
M/@!.F"T\`F4Q``/'N-^F`>@``QBZ9$)@ZP`"$'@#`Q@E`!.0/``2D#X!HR@F
M`,(P+0#0@"T`#8@\`*\H)@`2;OH`$C%X`,TP)0`%*#P`!2@^``8P/`"P*"T`
M!C`^`*8H+0`9?[C?I@'P`!G(N@'Y>"4`!8`\`!"`/@!O<"8`PC`M`!&(/@#1
MB"T`$&[Z`=-P)@`0,7@`S3`E``YP/``.<#X`!C`\`=%P+0`&,#[?N`'X`<9P
M+0`2S[@``Q@\`!*0N@,RR"4`#I@\`P+`+0`#&#X`$Y@^`P/`+0'Y&"8`92@F
M`!-I>``3'OH!HV@E``4H/``%*#X`#6@\`P4H+0`-:#X`K2@M`!"/N``0@+H"
M,(@E``60/``2D#X#,1@FWZ8"```2;OH`;G`F``]X/``2&7@`PC`M``]X/@!M
M&"4`#G`\`,\P+0`.<#X`$W^X``,8/``3F+H!\W@E`,XP+0`#&#X`PS`MWZT"
M"`(O&"8`92@F`!G(/``&@#P!HF@M`!G(/@`%*#P`$(`^`;EH+0`%*#X!I6@M
M`!`9>``0+OH`91@E``,8/``#&#X!HV@M`!+'N``2D+H#$L`E``W(/-^E`A``
M&<@^`?@8)@`1B#P`HB@M`!&(/@!F,"8`&7%X`!D>^@"Q*"T!PW`E`!"/N``&
M,#P`$("Z`C"()0`&,#X`#G`\`*8H+0`.<#X#$3`FWZ,"&`"N*"T`S6@F``]X
M/``%D#P`8A@M``]X/@`-:#P`$I`^`&\8+0`-:#X`;1@M`!(Q>``2;OH`S3`E
M`!E_N``&,#P`&<BZ`?EX)0`&,#X`9A@MWZX"(`(O,"8`Q2@F`!C`/``#@#P!
MPG`M`!C`/@`%*#P`$(`^`=AP+0`%*#X!Q7`M`!!I>``0+OH!I6@E`!+'N``2
MD+H#$L`E``UH/`'X*"8`#6@^WZ8"*`'-<"T`HQ@F`!&(/``.R#P`PC`M`!&(
M/@`#&#P`&<@^`-$P+0`#&#X`PS`M`!DI>``9'OH`HR@E``4H/``%*#X`Q3`M
M`!"7N``0@+H"4)`E``:8/``3F#X#$A@FWZT",``3+OH`;G`F``]X/``3&7@!
MHF@M``]X/@!E&"4`#G`\`:]H+0`.<#X``Q@\`:YH+0`#&#X!HV@M`!F'N``9
MR+H"&8`E``V(/-^E`C@`$8@^`E`8)@`8P#P`HB@M`!C`/@!F,"8`$7EX`!$>
M^@"X*"T!XW@E`!/'N``&,#P`$YBZ`Q/`)0`&,#X`#W@\`*8H+0`/>#X"&#`F
MWZ,"0`"O*"T`S6@F`!*0/``%R#P`8A@M`!*0/@`-:#P`&<@^`'(8+0`-:#X`
M;1@M`!DQ>``9;OH`S3`E`!&7N``&,#P`$8BZ`E&0)0`&,#X`9A@MWZ\"2`,2
M,"8`Q2@F`!"`/``#F#P!XG@M`!"`/@`%*#P`$Y@^`?!X+0`%*#X!Y7@M`!-Q
M>``3+OH!Q7`E`!F'N``9R+H"&8`E``YP/`)0*"8`#G`^WZ8"4`'N>"T`HQ@F
M`!C`/``/B#P`PC`M`!C`/@`#&#P`$8@^`-@P+0`#&#X`PS`M`!%I>``1'OH!
MHV@E``UH/``-:#X`S3`M`!/'N``3F+H#$\`E``;(/``9R#X"&!@FWZX"6`!O
M>"8`&2EX`!D>^@`2D#P!PG`M`!*0/@"C*"4`#W@\`=)P+0`/>#X`!2@\`<]P
M+0`%*#X!Q7`M`!&7N``1B+H"49`E``Z8/``3F#X#$A@FWZT"8`!F,"8`$WEX
M`!,>^@`0@#P!HF@M`!"`/@'C>"4`!C`\`;!H+0`&,#X`#W@\`:9H+0`/>#X!
MKV@M`!F'N``9R+H"&8`E``V(/``1B#X"4!@FWZ4":``1-OH`;G`F`!C`/``1
M&7@`HB@M`!C`/@!F&"4`#G`\`+@H+0`.<#X``Q@\`*XH+0`#&#X`HR@M`!/'
MN``3F+H#$\`E``7(/``9R#X"&!@FWZ\"<``9-OH`;6@F`!*0/``9&7@!XG@M
M`&88)0`2D#X`#6@\``UH/@`1-[@!\G@M``,8/``1B+H`T3`E`>UX+0`#&#X#
M!G`F`>-X+=^C`G@!Q2@F`!"`/``/:#P`8A@M`!"`/@`%*#P`#6@^``4H/@!P
M&"T`#7;Z`&48+0`-*7@`KB@E`&48+0`9=[C?I0*``!G(N@'9<"4`HA`M`,XH
M)@"O>"8``Q@\`!C`/``#&#X`3!`M`!C`/@`/>#P``REX``-F^@!8$"T`#W@^
M`$\0+0"L*"4`11`M``(0/``"$#[\@@```&D8+0`-%[@`#6BZ`$T0)0`#&#P`
M`Q@^`$<X+0'(<"T`RS`M_(,`"``'.#S?HP*(``YP/``&,#S=0@````<X/@`.
M<#X`!C`^_(<`$/R.`!@08@`$_(8`(-^9@1@#(/@)`````-^_`KC?O`*PW[,"
MJ-^R`J#?L0*8W[`"D`/@``AGO0+`9[W_\/^\```\'``"`YG@+6><R>S?F8*8
M_[\`"`,@^`DD!`"`/`1G162$(P'\1```)`1WYP`$)'ADA*N)_$0`"#P$3%UD
MA&Y_``0@>/Q$`!`\!!`R9(14=OQ$`!@\!`P]9(0N'P`$(3C\1``@_$``*/Q`
M`#"L0`!XW[\`"-^\```#X``(9[T`$&>]_\#_O``P_[$`"/^P``#_OP`X_[4`
M*/^T`"#_LP`8_[(`$-R#`"@`!A#X`$,0+0`"$#P\'``"``(0/@.9X"T`0Q@K
M9YS)9`"`@"408``$`,"()=R#`#!D8P`!_(,`,-X#`##^`@`HC@0`>``1%WH`
M8A`M_@(`,!"``!]F$@`X)`(`0`!$$",`41@J$&```@(@,"4`0#`E`D0@+0"%
M$"L00``#`,"@)0"4$"T`H@`S`*00*Q!```(`II@M`),`,]^9@3`#(/@)````
M`(X"`'@D`P!``%00(11#`!NN`@!XWYF`6`(`("5G.3Q@`R#X"0(TB","8"@E
MWY.`6&85`'AF<SQ@*B(`0-^9@3`00``9`D48*Q!@``0`LA`K`E$0+0"B`#,`
MLA`K$$``!`(@,"4`L1`M`D(`,P(@,"4#(/@)`D`@):X1`'C?OP`XW[P`,-^U
M`"C?M``@W[,`&-^R`!#?L0`(W[````/@``AGO0!`````-!!@``0`LA`K`+40
M*Q1`__L`LA`K$$``!&2T`$`"5!`K%$#_]@`````D!@!``D`@)0,@^`DF,?_`
M`F#()0,@^`D"`"`E$`#_T@*`*"5GO?_`_[P`,/^U`"C_LP`8_[$`"/^P``#_
MOP`X_[0`(/^R`!#<L@`H/!P``@`2$/H#F>`M,$(`/V><QZ0`0!@E9+4`."1"
M``$"HQ@MWY.`6`"`B"4D!/^`W+0`,*!D```H0P`YWYF"L`"@@"4"HB`M%&``
M8V9S/&`D!@!``,(P(P,@^`D``"@E`F#()0,@^`D"`"`EWYF"L"0&`#@``"@E
M`J`@)0,@^`D``````!06.J("`'``%!0ZH@(`<0`4$CJB`@!R`!(6.J("`'0`
M$A0ZH@(`=0(`("4`$A(Z`F#():(4`'.B`@!V`R#X":(2`'?>`@``WYF!:``"
M%CJB(@``W@(```(`("4``A0ZHB(``=X"`````A(ZHB(``MX"``"B(@`#W@(`
M"``"%CJB(@`$W@(`"``"%#JB(@`%W@(`"``"$CJB(@`&W@(`"*(B``?>`@`0
M``(6.J(B``C>`@`0``(4.J(B``G>`@`0``(2.J(B``K>`@`0HB(`"]X"`!@`
M`A8ZHB(`#-X"`!@``A0ZHB(`#=X"`!@``A(ZHB(`#MX"`!BB(@`/W@(`(``"
M%CJB(@`0W@(`(``"%#JB(@`1W@(`(``"$CJB(@`2W@(`(`,@^`FB(@`3W[\`
M.-^\`##?M0`HW[0`(-^S`!C?L@`0W[$`"-^P```#X``(9[T`0"0&`#@`PC`C
M$`#_I@``*"4`````9[W_X/^\`!`\'``"`YG@+6><Q9#?@X`X)`+__]QYG^#_
MOP`8_[$`"!,B``C_L```)!'__V1PG^`#(/@)9A#_^-X9```7,?_\`````-^_
M`!C?O``0W[$`"-^P```#X``(9[T`(````````````````-^9@!`#X'@E`R#X
M"608`&C?F8`0`^!X)0,@^`ED&`!EWYF`$`/@>"4#(/@)9!@`9-^9@!`#X'@E
M`R#X"608`&/?F8`0`^!X)0,@^`ED&`!BWYF`$`/@>"4#(/@)9!@`8=^9@!`#
MX'@E`R#X"608`&#?F8`0`^!X)0,@^`ED&`!?WYF`$`/@>"4#(/@)9!@`7=^9
M@!`#X'@E`R#X"608`%S?F8`0`^!X)0,@^`ED&`!;WYF`$`/@>"4#(/@)9!@`
M6M^9@!`#X'@E`R#X"608`%G?F8`0`^!X)0,@^`ED&`!8WYF`$`/@>"4#(/@)
M9!@`5]^9@!`#X'@E`R#X"608`%;?F8`0`^!X)0,@^`ED&`!5WYF`$`/@>"4#
M(/@)9!@`5-^9@!`#X'@E`R#X"608`%/?F8`0`^!X)0,@^`ED&`!2WYF`$`/@
M>"4#(/@)9!@`4=^9@!`#X'@E`R#X"608`%#?F8`0`^!X)0,@^`ED&`!.WYF`
M$`/@>"4#(/@)9!@`3=^9@!`#X'@E`R#X"608`$S?F8`0`^!X)0,@^`ED&`!*
MWYF`$`/@>"4#(/@)9!@`2=^9@!`#X'@E`R#X"608`$C?F8`0`^!X)0,@^`ED
M&`!'WYF`$`/@>"4#(/@)9!@`1M^9@!`#X'@E`R#X"608`$7?F8`0`^!X)0,@
M^`ED&`!$WYF`$`/@>"4#(/@)9!@`0M^9@!`#X'@E`R#X"608`$'?F8`0`^!X
M)0,@^`ED&``_WYF`$`/@>"4#(/@)9!@`/-^9@!`#X'@E`R#X"608`#O?F8`0
M`^!X)0,@^`ED&``ZWYF`$`/@>"4#(/@)9!@`.=^9@!`#X'@E`R#X"608`#??
MF8`0`^!X)0,@^`ED&``VWYF`$`/@>"4#(/@)9!@`-=^9@!`#X'@E`R#X"608
M`#3?F8`0`^!X)0,@^`ED&``QWYF`$`/@>"4#(/@)9!@`,-^9@!`#X'@E`R#X
M"608`"_?F8`0`^!X)0,@^`ED&``NWYF`$`/@>"4#(/@)9!@`+-^9@!`#X'@E
M`R#X"608`"O?F8`0`^!X)0,@^`ED&``JWYF`$`/@>"4#(/@)9!@`*=^9@!`#
MX'@E`R#X"608`"C?F8`0`^!X)0,@^`ED&``GWYF`$`/@>"4#(/@)9!@`)M^9
M@!`#X'@E`R#X"608`"7?F8`0`^!X)0,@^`ED&``D````````````````````
M`&>]_^#_O``0_[\`&``````$$0`!``````.`$"4\'``")YS!>`.?X"W?F8!@
M`R#X"0````#?O``0W[\`&`/@``AGO0`@````````````````4$%27U1-4$1)
M4@```````%1-4$1)4@``5$5-4$1)4@!414U0`````%1-4```````+@``````
M```N+@```````"5S+R5S````1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R
M``````!);G1E<FYA;',Z.E!!4CHZ0D]/5`````!E>&4``````"]P<F]C+R5I
M+R5S``````!005)?5$5-4```````````4$%27U!23T=.04U%`````#H`````
M````+P`````````E<R5S)7,``%!%4DPU3$E"``````````!015),3$E"`%!%
M4DPU3U!4``````````!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!
M5TY%1```````4$%27T-,14%.`````````%!!4E]$14)51P````````!005)?
M0T%#2$4`````````4$%27T=,3T)!3%]$14)51P``````````4$%27T=,3T)!
M3%]435!$25(`````````4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%
M04X``````````%!!4E]#3$5!3CT````````Q`````````$Q$7TQ)0E)!4EE?
M4$%42`!365-414T``"]T;7``````55-%4@````!54T523D%-10``````````
M)3`R>`````!P87(M`````"5S)7,E<R5S```````````E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*
M````````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H
M<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``
M`````%!!5$@`````<&%R;``````N<&%R`````"5S)7-C86-H92TE<R5S```E
M<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P``````````&```````
M``!P97)L`````#``````````4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP
M-3(```!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````````
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S
M(&9A:6QE9"`H97)R;F\])6DI"@``````````+64````````M+0```````&5V
M86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P
M.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A
M<E]P;#L*;7D@*"1005)?34%'24,L("1P87)?=&5M<"P@)'!R;V=N86UE+"!`
M=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,
M14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S
M96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z
M.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I
M;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E
M<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M
M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@
M;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-
M4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID
M:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@
M,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T
M;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@
M+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE
M;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G
M)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N
M86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B([
M"G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O
M8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"
M14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT
M97)N86QS.CI005(Z.D)/3U0["B1005)?34%'24,@/2`B7&Y005(N<&U<;B([
M"F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!
M4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@
M/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/
M(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?
M9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G
M+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@
M*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?
M7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64@;W(@
M;&%S=#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1C
M:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I
M>F4@/#T@)&-H=6YK7W-I>F4I('L*)&UA9VEC7W!O<R`](#`["GT@96QS:68@
M*"AM>2`D;2`]("1S:7IE("4@)&-H=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?
M<&]S(#T@)'-I>F4@+2`D;3L*?2!E;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE
M("T@)&-H=6YK7W-I>F4["GT*=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS
M965K(%]&2"P@)&UA9VEC7W!O<RP@,#L*<F5A9"!?1D@L("1B=68L("1C:'5N
M:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN
M9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["B1M86=I8U]P;W,@*ST@
M)&D["FQA<W0["GT*)&UA9VEC7W!O<R`M/2`D8VAU;FM?<VEZ93L*?0IL87-T
M(&EF("1M86=I8U]P;W,@/"`P.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L
M(#`["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M
M(#0@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?
M1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@
M("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B
M"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA
M;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B
M+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX
M?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@
M*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@
M*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI
M)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B
M=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@
M/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE
M?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H
M;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE
M;F%M92`](%]S879E7V%S*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D[
M"F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER
M95]L:7-T>R1F=6QL;F%M97T@/0HD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]
M('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M
M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U
M8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D
M;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`](&1E;&5T92`D<F5Q=6ER
M95]L:7-T>R1M;V1U;&5](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O
M;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N
M9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE
M.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F
M?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@
M)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O
M+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F
M:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO
M9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR
M97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@
M/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.
M0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H
M)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64[
M"GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S
M:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[
M)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T
M(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@
M("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B
M=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?
M05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I
M='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=]
M.PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I
M;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB
M7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@
M('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%2
M1U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!
M4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A
M<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*
M)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S
M=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE
M;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q
M(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q
M(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD
M8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L
M92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*
M?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O
M<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS
M:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!
M4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D
M14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H
M:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U
M:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$
M:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP
M.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D
M<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=
M.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP
M+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E
M861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E96YV(#T@9&\@>PII
M9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY
M;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>
M7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I]
M.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D
M<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=
M.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I
M<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B
M.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/
M.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ
M1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L
M"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD
M9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF
M("AD969I;F5D("1D871A7W!O<RD@>PIR96%D(%]&2"P@)&QO861E<BP@)&1A
M=&%?<&]S.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@
M/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@
M/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R
M+"`D,"D["GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM
M>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L
M(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B
M("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME
M>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I
M8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI
M*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*:68@*"1B=6YD;&4I('L*
M<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC
M(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET
M92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD
M"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*
M<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I
M;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L
M('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML
M:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@
M)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@
M>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@
M/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC
M*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE
M+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\
M7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L
M94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA
M<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B
M)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I
M;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF
M("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD[
M"F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D
M9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*
M:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*
M96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)&9H+"`G/#IR87<G
M+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C
M;VYT96YT(#T@/"1F:#X["F-L;W-E("1F:#L*4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\
M86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY
M*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%
M(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X
M>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@
M)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT
M*3L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"B1Z:7`M/G=R
M:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S
M=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N
M9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I
M9V5S=#HZ4TA!+3YN97<H,2D["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D;W5T
M.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E("1F:#L*)&-A8VAE7VYA;64@
M/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T
M,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(
M12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH
M)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN
M="@D4$%27TU!1TE#*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*
M97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I
M>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S
M(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R
M)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI:
M:7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ
M6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R
M;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;
M17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI
M=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ
M3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D
M>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q6UPD14Y6
M>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I
M;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE
M>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]
M("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@
M/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO
M*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*
M?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I
M;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA
M;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N
M8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R
M7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE
M(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M
M92(@=&\@(B1D97-T7VYA;64B72D["B1M96UB97(M/F5X=')A8W14;T9I;&5.
M86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@
M)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E
M.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S
M<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I
M;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@
M/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D
M;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E
M;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S
M92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z
M.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A
M=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E
M<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E
M<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@
M=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U
M:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%
M>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@
M0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4[
M"G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!0
M05(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@
M?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A
M;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"
M=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R
M92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS
M8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A
M<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[
M4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N
M.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%2
M7U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q4
M14U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N
M9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W
M=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D
M("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U
M<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D
M("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R
M;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%
M32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D
M<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA
M;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!
M3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P
M96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T
M(')E860@(B1P<F]G;F%M92(Z("0A73L*<V5E:R`D9F@L("TQ."P@,CL*;7D@
M)&)U9CL*<F5A9"`D9F@L("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%
M(BD@>PIS965K("1F:"P@+34X+"`R.PIR96%D("1F:"P@)&)U9BP@-#$["B1B
M=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A
M8VAE+21B=68B.PI]"F5L<V4@>PIM>2`D9&EG97-T(#T@979A;`I["G)E<75I
M<F4@1&EG97-T.CI32$$["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I
M.PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#
M86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["B1C='@M/F%D9&9I;&4H)&9H
M*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T.PI]('Q\("1M=&EM93L*
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21D:6=E<W0B.PI]
M"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!
M4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S
M=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.
M5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D
M;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@
M(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY
M("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXZ
M<F%W)RP@)'1E;7!N86UE(&]R(&1I92!Q<5M#86XG="!W<FET92`B)'1E;7!N
M86UE(CH@)"%=.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H
M;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE
M*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*
M?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@
M*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'
M3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M
M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N
M86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S
M='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@
M;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]
M"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE
M("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I
M<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI
M('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@
M)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%
M)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX
M7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.
M04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\
M(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B
M.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG
M971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ
M1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@
M<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?
M9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U
M8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK
M*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)
M6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'
M($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT[
M"GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6
M>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T
M<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B
M7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM0
M05)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H
M(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]
M('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%
M3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH
M7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D
M;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@
M(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U
M<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1?
M?2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E
M;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G
M92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN
M9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ
M($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@
M9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@
M)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D
M0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>
M7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?
M15)23U(["C$["E]?14Y$7U\*`````````````%]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@``````````!P97)L>'-I+F,`````````````````
M```O;&EB+VQD+6UU<VPM;6EP<S8T+7-F+G-O+C$`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#__________P``````````________
M__\``````````````````%\0````````7R````````!?*````````%\P````
M````7S@``````````/____\```````````````````````!BR```````````
M````````````````````````````````@`````````````````!>P```````
M`!>P````````&0````````(``````````:!8```````!HX@```````&?^```
M````````````````'=@````````>V````````0``````````)A`````````X
MJ````````";H````````+K@````````O`````````"Y$````````*$@`````
M``!69````````%;L````````6*P````````L%````````#`4````````*M``
M```````JI````````:!`````````.[0```````!:P```````````````````
M``````````!>H````````%Z0````````7H````````!><````````%Y@````
M````7E````````!>0````````%XP````````7B```````````````````%X0
M````````7@````````!=\````````%W@````````````````````````````
M`%W0````````7<````````!=L````````%V@``````````````````!=D```
M`````%V`````````77````````!=8`````````````````````````````!=
M4```````````````````74````````!=,```````````````````72``````
M``!=$````````%T`````````7/````````!<X````````%S0````````7,``
M`````````````````%RP````````7*````````!<D```````````````````
M7(````````!<<````````%Q@````````7%````````!<0````````%PP````
M````7"````````!<$````````%P`````````6_````````!;X````````%O0
M````````6\````````!;L```````````````````6Z````````!;D```````
M`%N`````````6W````````!;8````````%M0````````6T``````````````
M````````````````6S````````&CB$=#0SH@*$%L<&EN92`Q,"XS+C%?9VET
M,C`R,3`V,C4I(#$P+C,N,2`R,#(Q,#8R-0```````!T`D````/____@`````
M`````````!`````=````'P``'S"0?P``____^```````````````4````!T`
M```?```@+)`!``#____X```````````````P````'0```!\``""4D`\``/__
M__@``````````````%`````=````'P``(4R0_P``____^``````````````!
M0````!T````?```C))`#``#____X``````````````$`````'0```!\``"/4
MD'\``/____@``````````````&`````=````'P``)A"0````____^```````
M````````$````!T````?```F:)`!``#____X```````````````@````'0``
M`!\``";HD`\``/____@`````````````(&`````=````'P``*#``````````
M`````````````````````!T````?```H2-#_``#____X`````````````!%0
M````'0```!\``"JD```````````````````````````````=````'P``*M"0
M`0``____^```````````````(````!T````?```L%)!_``#____X````````
M``````"`````'0```!\``"Y$D`$``/____@``````````````"`````=````
M'P``+KB0````____^```````````````$````!T````?```O`)`/``#____X
M```````````````P````'0```!\``#`4T/\``/____@`````````````@?``
M```=````'P``.*B0#P``____^```````````````,````!T````?```[M)`#
M``#____X```````````````@````'0```!\``!D`D`\``/____@`````````
M`````%`````=````'P``/&"0#P``____^``````````````"P````!T````?
M``!69)````#____X```````````````0````'0```!\``%;LD#\``/____@`
M`````````````$`````=````'P``6*R0/P``____^```````````````0```
M`!T````?00````]G;G4``0````<$`P`N<VAS=')T86(`+DU)4%,N86)I9FQA
M9W,`+DU)4%,N;W!T:6]N<P`N9'EN86UI8P`N:&%S:``N9'EN<WEM`"YD>6YS
M='(`+G)E;"YD>6X`+FEN:70`+G1E>'0`+DU)4%,N<W1U8G,`+F9I;FD`+G)O
M9&%T80`N:6YT97)P`"YE:%]F<F%M90`N8W1O<G,`+F1T;W)S`"YD871A`"YR
M;&1?;6%P`"YG;W0`+G-D871A`"YB<W,`+F-O;6UE;G0`+G!D<@`N9VYU+F%T
M=')I8G5T97,`````````````````````````````````````````````````
M``````````````````````````````````````````MP```J``````````(`
M```````".`````````(X`````````!@````````````````````(````````
M`!@````:<```#0`````(```"`````````E`````````"4`````````$8````
M````````````````"``````````!````*`````8``````````@````````-H
M`````````V@````````"``````8```````````````@`````````$````#$`
M```%``````````(````````%:`````````5H`````````S`````%````````
M```````(``````````0````W````"P`````````"````````")@````````(
MF`````````G8````!@````(`````````"``````````8````/P````,`````
M`````@```````!)P````````$G`````````$D`````````````````````$`
M`````````````$<````)``````````(````````7`````````!<`````````
M`(`````%```````````````(`````````!````!0`````0`````````&````
M````%[`````````7L`````````!H````````````````````"```````````
M````5@````$`````````!@```````!D`````````&0````````!",```````
M`````````````0```````````````%P````!``````````8```````!;,```
M`````%LP`````````Y`````````````````````(``````````````!H````
M`0`````````&````````7L````````!>P`````````!$````````````````
M````"```````````````;@````$``````````@```````%\0````````7Q``
M```````_@````````````````````!```````````````'8````!````````
M``(```````">D````````)Z0`````````!P````````````````````!````
M``````````!^`````0`````````#```````!G]P```````"?W``````````$
M````````````````````!```````````````B`````$``````````P``````
M`9_@````````G^``````````$`````````````````````@`````````````
M`(\````!``````````,```````&?\````````)_P`````````!``````````
M```````````(``````````````"6`````0`````````#```````!H```````
M``"@``````````!0````````````````````$```````````````G`````$`
M`````````P```````:!0````````H%``````````"```````````````````
M``@``````````````*4````!`````!````,```````&@8````````*!@````
M`````R@````````````````````0``````````@```"J`````0`````0```#
M```````!HX@```````"CB``````````(````````````````````"```````
M````````L0````@``````````P```````:.0````````HY`````````08```
M`````````````````!```````````````+8````!`````````#``````````
M`````````*.0`````````#$````````````````````!``````````$```"_
M`````0````````````````````````````"CQ`````````-`````````````
M````````!```````````````Q&____4`````````````````````````````
MIP0`````````$`````````````````````$```````````````$````#````
M`````````````````````````*<4`````````-0````````````````````!
(````````````
